@@ -122,6 +122,12 @@ def fn_ktest(*fnkwargs):
     (ds.text, {"min_size": 10, "max_size": 9}),
     (ds.text, {"alphabet": [1]}),
     (ds.text, {"alphabet": ["abc"]}),
+    (ds.text, {"alphabet": ds.just("abc")}),
+    (ds.text, {"alphabet": ds.sampled_from(["abc", "def"])}),
+    (ds.text, {"alphabet": ds.just(123)}),
+    (ds.text, {"alphabet": ds.sampled_from([123, 456])}),
+    (ds.text, {"alphabet": ds.builds(lambda: "abc")}),
+    (ds.text, {"alphabet": ds.builds(lambda: 123)}),
     (ds.binary, {"min_size": 10, "max_size": 9}),
     (ds.floats, {"min_value": math.nan}),
     (ds.floats, {"min_value": "0"}),
@@ -247,7 +253,9 @@ def test_validates_keyword_arguments(fn, kwargs):
     (ds.text, {"alphabet": "abc"}),
     (ds.text, {"alphabet": set("abc")}),
     (ds.text, {"alphabet": ""}),
+    (ds.text, {"alphabet": ds.just("a")}),
     (ds.text, {"alphabet": ds.sampled_from("abc")}),
+    (ds.text, {"alphabet": ds.builds(lambda: "a")}),
     (ds.characters, {"whitelist_categories": ["N"]}),
     (ds.characters, {"blacklist_categories": []}),
     (ds.ip_addresses, {}),
